Prints a summary of a peak_list object, including the number of
samples, wavelengths, fit method, and total number of peaks.
Usage
# S3 method for class 'peak_list'
print(x, ...)Prints a summary of a peak_list object, including the number of
samples, wavelengths, fit method, and total number of peaks.
# S3 method for class 'peak_list'
print(x, ...)