Skip to contents

Prints basic statistics about peak_table to the console (e.g., the number of peaks, wavelengths, range of intensities, etc).

Usage

# S3 method for class 'peak_table'
summary(object, ...)

Arguments

object

A peak_table object.

...

Additional arguments (currently unused).

Value

A list containing basic information about the supplied peak_table.

Author

Ethan Bass