Reference spectra are selected either as the spectrum with maximum intensity
("max.int") or as the spectrum with the highest average correlation to all
other spectra in the peak table ("max.cor").
Usage
attach_ref_spectra(peak_table, chrom_list, ref = c("max.cor", "max.int"))Arguments
- peak_table
A
peak_tableobject created byget_peaktable.- chrom_list
Optional list of chromatograms (timepoints × wavelengths). If
NULL, the function attempts to retrieve the originalchrom_listused to generatepeak_table.- ref
Method for selecting reference spectra. Options are
"max.int"(maximum intensity) or"max.cor"(maximum average correlation).