Returns the dimensions of a peak_table, where the first dimension is
the number of samples and the second dimension is the number of peaks.
Usage
# S3 method for class 'peak_table'
dim(x)Arguments
- x
A
peak_tableobject.
Returns the dimensions of a peak_table, where the first dimension is
the number of samples and the second dimension is the number of peaks.
# S3 method for class 'peak_table'
dim(x)A peak_table object.