Utility function for filtering peaks from a peak_list object. Peaks can be
filtered according to height, area, standard deviation, and/or retention time.
Arguments
- peak_list
A
peak_listobject, consisting of a nested list of peak tables, where the first level is the sample, and the second level is the spectral component. Every component is described by adata.framewhere every row represents a peak, and the columns contain information on retention time, peak shape, height, and area.- min_height
Minimum peak height.
- min_area
Minimum peak area.
- min_sd
Minimal standard deviation.
- max_sd
Maximum standard deviation.
- min_rt
Minimum retention time.
- max_rt
Maximum retention time.