Plots ptw alignments.
Arguments
- x
A
ptw_listobject created bycorrect_rt.- what
What type of plot to return. Either
tracesorheatmap.- engine
What plotting engine to use. One of
base,ggplot, orplotly.- lambdas
Which lambdas to plot.
- show_legend
Logical. Whether to include sample legend.
- ...
Additional arguments (placeholder).
Value
A plotly or ggplot object when engine = "plotly" or
engine = "ggplot", respectively. No value is returned when
engine = "base".
Details
Plots PTW alignments at the specified wavelength (lambda) either as
individual traces or as a heatmap, according to the value of what. The
plot can be produced using either base R graphics, ggplot2, or plotly,
according to the value of the engine argument.
Examples
if (FALSE) { # interactive()
data(Sa_pr)
warp <- correct_rt(chrom_list = Sa_pr, what = "models", lambdas = 210)
plot(warp)
}